/*
 * Copyright (c) 2000 Blue Mug, Inc.  All Rights Reserved.
 */

#include <target/assert.h>
#include <target/crc.h>
#include <target/command.h>
#include <target/herrno.h>
#include <target/str.h>
#include <target/io.h>
#include <ep93xx/ioregs.h>
#include "board.h"

typedef enum medium_type {
	MEDIUM_SERIAL = 0,
} medium_t;
static medium_t current_medium;

int hgetchar(void)
{
#if defined(CONSOLE)
#  if CONSOLE == 0
	if(jumper_mode == 1){
		while (IO_UART1FR & UARTFR_RXFE);
		return IO_UART1DR & 0xff;
	}else{
		while (IO_UART2FR & UARTFR_RXFE);
		return IO_UART2DR & 0xff;
	}
#  elif CONSOLE == 1
  	while (IO_UART2FR & UARTFR_RXFE);
	return IO_UART2DR & 0xff;
#  else
#    error "unknown CONSOLE value"
#  endif
#else
	return 0;
#endif
}

int hputchar(int c)
{
#if defined(CONSOLE)
#  if CONSOLE == 0
	if(jumper_mode == 1){
		while (IO_UART1FR & UARTFR_TXFF);
		IO_UART1DR = c;
	}else{
		while (IO_UART2FR & UARTFR_TXFF);
		IO_UART2DR = c;
	}
#  elif CONSOLE == 1
  	while (IO_UART2FR & UARTFR_TXFF);
	IO_UART2DR = c;
#  else
#    error "unknown CONSOLE value"
#  endif
#else
	return 0;
#endif
}

int hgetblock(unsigned char *dst, int count)
{
	int remain = count;
	while (remain--)
		*dst++ = hgetchar();
	return count;
}

/*
 * This works for now, since medium only affects downstream data, not
 * replies from the target to the host.  Once we add upstream media
 * switching, we'll have to implement a delayed media switch that
 * allows the successful command return value to go out along the old
 * medium.
 */
static int medium_cmdfunc(int argc, char *argv[])
{
	medium_t medium;
	
	if (argc != 2)
		return -H_EUSAGE;
	++argv;
	if (!strcmp(*argv, "serial"))
		medium = MEDIUM_SERIAL;
	else
		return -H_EINVAL;
	if (medium == current_medium)
		return 0;

	current_medium = medium;
	return 0;
}

const command_t medium_command =
	{ "medium", "<medium name>",
	  "select communication medium",
	  &medium_cmdfunc };

