/*
 * Copyright (c) 2004 Atmark Techno, Inc.  All Rights Reserved.
 */

#ifndef _HERMIT_MEMREGIONS_H
#define _HERMIT_MEMREGIONS_H

#define FLASH_BANK1_START	0x60000000
#define FLASH_BANK1_SIZE	0x00400000

#define FLASH_BOOTLOADER_START  FLASH_BANK1_START
#define FLASH_BOOTLOADER_SIZE   0x10000
#define FLASH_KERNEL_START      (FLASH_BOOTLOADER_START + FLASH_BOOTLOADER_SIZE)
#define FLASH_KERNEL_SIZE       0x170000
#define FLASH_USERLAND_START    (FLASH_KERNEL_START + FLASH_KERNEL_SIZE)
#define FLASH_USERLAND_SIZE     0x270000
#define FLASH_CONFIG_START      (FLASH_USERLAND_START + FLASH_USERLAND_SIZE)
#define FLASH_CONFIG_SIZE       (FLASH_BANK1_START + FLASH_BANK1_SIZE - FLASH_CONFIG_START)

#define FLASH_OPTION_START      (FLASH_BOOTLOADER_START + 0xe000)
#define FLASH_OPTION_SIZE       0x2000

#define FLASH_BOOTLOADER_NAME   "bootloader"
#define FLASH_KERNEL_NAME       "kernel"
#define FLASH_USERLAND_NAME     "userland"
#define FLASH_CONFIG_NAME       "config"

#define FLASH_BOOTLOADER_BLOCK  "8x8K/l"
#define FLASH_KERNEL_BLOCK      "23x64K"
#define FLASH_USERLAND_BLOCK    "39x64K"
#define FLASH_CONFIG_BLOCK      "8x8K"

#define MTDPARTS "mtdparts=armadillo210-nor:0x10000(bootloader)ro,0x170000(kernel),0x270000(userland),-(config)"

#define SRAM_START		0x80014000
#define SRAM_SIZE		0x00001100

#define BOOTROM_START		0x80090000
#define BOOTROM_SIZE		0x00004000

#define DRAM1_START		0xC0000000
#define DRAM1_SIZE		0x00800000
#define DRAM2_START		0xC1000000
#define DRAM2_SIZE		0x00800000
#define DRAM3_START		0xC4800000
#define DRAM3_SIZE		0x01000000

/*
 * External I/O regions are remapped by boot mode as well.
 */
#ifdef BOOTMODE
#define EXT_CS8900_BASE		0x50000300
#else
#define EXT_CS8900_BASE		0x20000300
#endif

#endif /* _HERMIT_MEMREGIONS_H */
